Citation
========

If you use Cell-ACDC in your publication, please cite:

   Francesco Padovani, Benedikt Mairhörmann, Pascal Falter-Braun, Jette
   Lengefeld, and Kurt M. Schmoller *Segmentation, tracking and cell
   cycle analysis of live-cell imaging data with Cell-ACDC*. BMC Biol
   20, 174 (2022) https://doi.org/10.1186/s12915-022-01372-6

.. important:: 

   Wwhen citing Cell-ACDC make sure to also cite the paper of the 
   segmentation models and trackers you used! 
   Below you find the links to the models currently available in Cell-ACDC.

.. include:: _models_list.rst
